@@ -1,42 +1,17 @@
 from . import _LOGGER
 
 from .device import _WiserDevice
-from .helpers import _WiserBattery, _WiserTemperatureFunctions as tf
+from .helpers import _WiserBattery
+from .helpers import _WiserTemperatureFunctions as tf
 from .rest_controller import _WiserRestController
 
 from .const import (
-    WISERROOMSTAT
+    WISERROOMSTAT,
+    WISERDEVICE
 )
 
 import inspect
 
-class _WiserRoomStatCollection(object):
-    """Class holding all wiser room stats"""
-
-    def __init__(self):
-        self._roomstats = []
-
-    @property
-    def all(self) -> dict:
-        return list(self._roomstats)
-
-    @property
-    def count(self) -> int:
-        return len(self.all)
-
-    # Roomstats
-    def get_by_id(self, id: int):
-        """
-        Gets a RoomStat object from the RoomStats id
-        param id: id of room stat
-        return: _WiserRoomStat object
-        """
-        for roomstat in self.all:
-            if roomstat.id == id:
-                return roomstat
-        return None
-
-
 class _WiserRoomStat(_WiserDevice):
     """Class representing a Wiser Room Stat device"""
 
@@ -47,13 +22,16 @@ class _WiserRoomStat(_WiserDevice):
         self._device_lock_enabled = data.get("DeviceLockEnabled", False)
         self._indentify_active = data.get("IdentifyActive", False)
 
-    def _send_command(self, cmd: dict):
+    def _send_command(self, cmd: dict, device_level: bool = False) -> bool:
         """
         Send control command to the room stat
         param cmd: json command structure
         return: boolen - true = success, false = failed
         """
-        result = self._wiser_rest_controller._send_command(WISERROOMSTAT.format(self.id), cmd)
+        if device_level:
+            result = self._wiser_rest_controller._send_command(WISERDEVICE.format(self.id), cmd)
+        else:
+            result = self._wiser_rest_controller._send_command(WISERROOMSTAT.format(self.id), cmd)
         if result:
             _LOGGER.debug(
                 "Wiser room stat - {} command successful".format(
@@ -63,7 +41,7 @@ class _WiserRoomStat(_WiserDevice):
         return result
 
     @property
-    def battery(self):
+    def battery(self) -> _WiserBattery:
         """Get the battery information for the room stat"""
         return _WiserBattery(self._data)
 
@@ -93,7 +71,7 @@ class _WiserRoomStat(_WiserDevice):
         Set the device lock setting on the room stat
         param enabled: turn on or off
         """
-        return self._send_command({"DeviceLockEnabled": enable})
+        return self._send_command({"DeviceLockEnabled": enable}, True)
 
     @property
     def identify(self) -> bool:
@@ -106,5 +84,32 @@ class _WiserRoomStat(_WiserDevice):
         Set the identify function setting on the room stat
         param enabled: turn on or off
         """
-        if self._send_command({"Identify": enable}):
-            self._indentify_active = enable
\ No newline at end of file
+        if self._send_command({"Identify": enable}, True):
+            self._indentify_active = enable
+
+
+class _WiserRoomStatCollection(object):
+    """Class holding all wiser room stats"""
+
+    def __init__(self):
+        self._roomstats = []
+
+    @property
+    def all(self) -> list:
+        return list(self._roomstats)
+
+    @property
+    def count(self) -> int:
+        return len(self.all)
+
+    # Roomstats
+    def get_by_id(self, id: int) -> _WiserRoomStat:
+        """
+        Gets a RoomStat object from the RoomStats id
+        param id: id of room stat
+        return: _WiserRoomStat object
+        """
+        for roomstat in self.all:
+            if roomstat.id == id:
+                return roomstat
+        return None
\ No newline at end of file
