@@ -1,46 +1,14 @@
 from . import _LOGGER
 
-from .helpers import _WiserBattery
 from .device import _WiserDevice
-from .helpers import _WiserTemperatureFunctions as tf
+from .helpers import _WiserTemperatureFunctions as tf, _WiserBattery
 from .rest_controller import _WiserRestController
 
-from .const import WISERSMARTVALVE
+from .const import WISERSMARTVALVE, WISERDEVICE
 
 import inspect
 
 
-class _WiserSmartValveCollection(object):
-    """Class holding all wiser smart valves"""
-
-    def __init__(self):
-        self._smartvalves = []
-
-    @property
-    def all(self) -> dict:
-        return list(self._smartvalves)
-
-    @property
-    def count(self) -> int:
-        return len(self.all)
-
-    def get_by_id(self, id: int):
-        """
-        Gets a SmartValve object from the SmartValves id
-        param id: id of smart valve
-        return: _WiserSmartValve object
-        """
-        try:
-            return [
-                smartvalve for smartvalve in self.all if smartvalve.id == id
-            ][0]
-        except IndexError:
-            return None
-
-    def get_by_room_name(self, room_name:str):
-        pass
-    
-
 class _WiserSmartValve(_WiserDevice):
     """Class representing a Wiser Smart Valve device"""
 
@@ -51,13 +19,16 @@ class _WiserSmartValve(_WiserDevice):
         self._device_lock_enabled = data.get("DeviceLockEnabled", False)
         self._indentify_active = data.get("IdentifyActive", False)
 
-    def _send_command(self, cmd: dict):
+    def _send_command(self, cmd: dict, device_level: bool = False):
         """
         Send control command to the smart valve
         param cmd: json command structure
         return: boolen - true = success, false = failed
         """
-        result = self._wiser_rest_controller._send_command(WISERSMARTVALVE.format(self.id), cmd)
+        if device_level:
+            result = self._wiser_rest_controller._send_command(WISERDEVICE.format(self.id), cmd)
+        else:
+            result = self._wiser_rest_controller._send_command(WISERSMARTVALVE.format(self.id), cmd)
         if result:
             _LOGGER.debug(
                 "Wiser smart valve - {} command successful".format(
@@ -78,7 +49,7 @@ class _WiserSmartValve(_WiserDevice):
 
     @device_lock_enabled.setter
     def device_lock_enabled(self, enable: bool):
-        if self._send_command({"DeviceLockEnabled": enable}):
+        if self._send_command({"DeviceLockEnabled": enable}, True):
             self._device_lock_enabled = enable
 
     @property
@@ -98,7 +69,7 @@ class _WiserSmartValve(_WiserDevice):
 
     @identify.setter
     def identify(self, enable: bool = False):
-        if self._send_command({"Identify": enable}):
+        if self._send_command({"Identify": enable}, True):
             self._indentify_active = enable
 
     @property
@@ -109,4 +80,36 @@ class _WiserSmartValve(_WiserDevice):
     @property
     def percentage_demand(self) -> int:
         """Get the current percentage demand of the smart valve"""
-        return self._device_type_data.get("PercentageDemand")
\ No newline at end of file
+        return self._device_type_data.get("PercentageDemand")
+        
+
+class _WiserSmartValveCollection(object):
+    """Class holding all wiser smart valves"""
+
+    def __init__(self):
+        self._smartvalves = []
+
+    @property
+    def all(self) -> dict:
+        return list(self._smartvalves)
+
+    @property
+    def count(self) -> int:
+        return len(self.all)
+
+    def get_by_id(self, id: int) -> _WiserSmartValve:
+        """
+        Gets a SmartValve object from the SmartValves id
+        param id: id of smart valve
+        return: _WiserSmartValve object
+        """
+        try:
+            return [
+                smartvalve for smartvalve in self.all if smartvalve.id == id
+            ][0]
+        except IndexError:
+            return None
+
+    def get_by_room_name(self, room_name:str) -> _WiserSmartValve:
+        pass
+    
